#!/bin/sh
set -e

if [ "$#" -ne 1 ]; then
    echo 'Need exactly one argument (system name).'
    false
fi
if [ ! "$1" = "eeepc" ] && [ ! "$1" = "x200s" ]; then
    echo "Need legal system name."
    false
fi
system_name="$1"

public_repos_dir="${HOME}/public_repos"
config_tree_prefix="${public_repos_dir}/config"
path_borgscript="${config_tree_prefix}/all_new_2018/borg.sh"
config_tree_buster="${config_tree_prefix}/buster"
setup_scripts_dir="${config_tree_buster}/setup_scripts"
repos_list_file="${public_repos_dir}/repos"
dir_secrets="${HOME}/tmp_secrets"
borgkeys_dir=~/.config/borg/keys
borgrepos_file=~/.borgrepos
ssh_dir=~/.ssh
authinfo_file=.authinfo
maildir=~/mail/maildir

ensure_repo() {
    repo_name="${1}"
    if [ ! -d "${public_repos_dir}/${repo_name}" ]; then
        cd "${public_repos_dir}"
        git clone plom@plomlompom.com:/var/public_repos/${repo_name}
    fi
}

# Set up iniitial non-public parts of infrastructure: SSH authentication.
cd "${dir_secrets}"
mkdir -p "${ssh_dir}"
echo "Setting up .ssh"
cp id_rsa ~/.ssh
stty -echo
ssh-keygen -y -f ~/.ssh/id_rsa > ~/.ssh/id_rsa.pub
stty echo
eval $(ssh-agent)
ssh-add
ssh-keyscan -H "plomlompom.com" >> ~/.ssh/known_hosts

# Clone config to copy dotfiles etc. from it.
cd
mkdir -p "${public_repos_dir}"
ensure_repo config
cd "${setup_scripts_dir}"
./copy_dirtree.sh "${config_tree_buster}/home_files" "${HOME}" minimal user "${system_name}"

# Set up native messenger for tridactyl.
version='ef9f02d0da258f68d7faf8898707f6d83d90d07a'
curl -fsSl "https://raw.githubusercontent.com/tridactyl/tridactyl/${version}/native/install.sh" | bash

# Set up further non-public parts of infrastructure.
cd "${dir_secrets}"
script -c 'gpg --import secret_keys.asc' /dev/null
tar xf borg_keyfiles.tar
mkdir -p "${borgkeys_dir}"
mv borg_keyfiles/* "${borgkeys_dir}"
# .authinfo may not be present on every secrets drive yet
if [ -f "${authinfo_file}" ]; then
    cp "${authinfo_file}" ~
fi
cd
rm -rf "${dir_secrets}"

# Sync org dir via borgbackup. For this we need the borgbackup servers
# in our .ssh/known_hosts file.
cat "${borgrepos_file}" | while read line; do
    first_char=$(echo "${line}" | cut -c1)
    if [ "${first_char}" = "#" ]; then
        continue
    fi
    server=$(echo "${line}" | sed 's/.*@//')
    ssh-keyscan "${server}" >> "${ssh_dir}"/known_hosts
done
BORG_PASSPHRASE="${SECRETS_PASS}" "${path_borgscript}" orgpull

# Fill ~/public_repos.
cat "${repos_list_file}" | while read line; do
    first_char=$(echo "${line}" | cut -c1)
    if [ "${first_char}" = "#" ]; then
        continue
    fi
    ensure_repo "${line}"
done

# Set up e-mail system. Note that we only do mbsync if the imap pass file
# is found. It may not be present on every secrets drive yet, so we have to
# deal with the possibility of it being absent at this point.
mkdir -p "${maildir}"  # expected by mbsync/isync
if [ -f "${HOME}/${authinfo_file}" ]; then
    mbsync -a
    notmuch new
fi

# Final note on how to integrate tridactyl.
echo "TODO: As tridactyl user, don't forget to do :source on the first Firefox run, wait a little while (Tridactyl needs to walk through all commands in the .tridactylrc) and then re-start."
